aboutsummaryrefslogtreecommitdiffstats
path: root/engine/battle/moveEffects/haze_effect.asm
diff options
context:
space:
mode:
authorxCrystal <rgr.crystal@gmail.com>2017-12-30 00:59:48 +0100
committerxCrystal <rgr.crystal@gmail.com>2017-12-30 00:59:48 +0100
commit94b9a86c8b9b6ea29653e98921205056790d6617 (patch)
treebff3c6553162ced5b7b463198e336036c805dd6e /engine/battle/moveEffects/haze_effect.asm
parentReplace hardcoded address offset (diff)
downloadpokeyellow-94b9a86c8b9b6ea29653e98921205056790d6617.tar.gz
pokeyellow-94b9a86c8b9b6ea29653e98921205056790d6617.tar.xz
pokeyellow-94b9a86c8b9b6ea29653e98921205056790d6617.zip
Uppercase battle status constants
Diffstat (limited to 'engine/battle/moveEffects/haze_effect.asm')
-rw-r--r--engine/battle/moveEffects/haze_effect.asm8
1 files changed, 4 insertions, 4 deletions
diff --git a/engine/battle/moveEffects/haze_effect.asm b/engine/battle/moveEffects/haze_effect.asm
index 06907bcc..47723ba2 100644
--- a/engine/battle/moveEffects/haze_effect.asm
+++ b/engine/battle/moveEffects/haze_effect.asm
@@ -47,14 +47,14 @@ HazeEffect_:
jp PrintText
CureVolatileStatuses:
- res Confused, [hl]
+ res CONFUSED, [hl]
inc hl ; BATTSTATUS2
ld a, [hl]
- ; clear UsingXAccuracy, ProtectedByMist, GettingPumped, and Seeded statuses
- and $ff ^((1 << UsingXAccuracy) | (1 << ProtectedByMist) | (1 << GettingPumped) | (1 << Seeded))
+ ; clear USING_X_ACCURACY, PROTECTED_BY_MIST, GETTING_PUMPED, and SEEDED statuses
+ and $ff ^((1 << USING_X_ACCURACY) | (1 << PROTECTED_BY_MIST) | (1 << GETTING_PUMPED) | (1 << SEEDED))
ld [hli], a ; BATTSTATUS3
ld a, [hl]
- and %11110000 | (1 << Transformed) ; clear Bad Poison, Reflect and Light Screen statuses
+ and %11110000 | (1 << TRANSFORMED) ; clear Bad Poison, Reflect and Light Screen statuses
ld [hl], a
ret